@@ -7,10 +7,7 @@ AUTO_FORMAT = 'AUTO'
 FALLBACK_FORMAT = 'JPEG'
 
 # Предпочитаемые расширения
-PREFERRED_EXTENSIONS = {
-    value: key
-    for key, value in Image.EXTENSION.items()
-}
+PREFERRED_EXTENSIONS = {value: key for key, value in Image.EXTENSION.items()}
 PREFERRED_EXTENSIONS['PNG'] = '.png'
 PREFERRED_EXTENSIONS['JPEG'] = '.jpg'
 PREFERRED_EXTENSIONS['JPEG2000'] = '.j2k'
